@@ -121,9 +121,10 @@ class LibcloudHTTPSConnection(httplib.HTTPSConnection):
 
         # replace * with alphanumeric and dash
         # replace . with literal .
+        # http://www.dns.net/dnsrd/trick.html#legal-hostnames
         valid_patterns = [
             re.compile('^' + pattern.replace(r".", r"\.") \
-                                    .replace(r"*", r"[0-9A-Za-z]+") + '$')
+                                    .replace(r"*", r"[0-9A-Za-z\-]+") + '$')
             for pattern in (set(common_name) | set(alt_names))]
 
         return any(
