@@ -56,15 +56,15 @@ NAMESPACE = 'http://s3.amazonaws.com/doc/%s/' % (API_VERSION)
 
 class S3Response(AWSBaseResponse):
 
-    valid_response_codes = [ httplib.NOT_FOUND, httplib.CONFLICT,
-                             httplib.BAD_REQUEST ]
+    valid_response_codes = [httplib.NOT_FOUND, httplib.CONFLICT,
+                            httplib.BAD_REQUEST]
 
     def success(self):
         i = int(self.status)
         return i >= 200 and i <= 299 or i in self.valid_response_codes
 
     def parse_error(self):
-        if self.status  in [ httplib.UNAUTHORIZED, httplib.FORBIDDEN ]:
+        if self.status in [httplib.UNAUTHORIZED, httplib.FORBIDDEN]:
             raise InvalidCredsError(self.body)
         elif self.status == httplib.MOVED_PERMANENTLY:
             raise LibcloudError('This bucket is located in a different ' +
@@ -73,9 +73,11 @@ class S3Response(AWSBaseResponse):
         raise LibcloudError('Unknown error. Status code: %d' % (self.status),
                             driver=S3StorageDriver)
 
+
 class S3RawResponse(S3Response, RawResponse):
     pass
 
+
 class S3Connection(ConnectionUserAndKey):
     """
     Repersents a single connection to the EC2 Endpoint
@@ -92,18 +94,16 @@ class S3Connection(ConnectionUserAndKey):
         return params
 
     def pre_connect_hook(self, params, headers):
-        params['Signature'] = self._get_aws_auth_param(method=self.method,
-                                                       headers=headers,
-                                                       params=params,
-                                                       expires=params['Expires'],
-                                                       secret_key=self.key,
-                                                       path=self.action)
+        params['Signature'] = self._get_aws_auth_param(
+            method=self.method, headers=headers, params=params,
+            expires=params['Expires'], secret_key=self.key, path=self.action)
         return params, headers
 
     def _get_aws_auth_param(self, method, headers, params, expires,
                             secret_key, path='/'):
         """
-        Signature = URL-Encode( Base64( HMAC-SHA1( YourSecretAccessKeyID, UTF-8-Encoding-Of( StringToSign ) ) ) );
+        Signature = URL-Encode( Base64( HMAC-SHA1( YourSecretAccessKeyID,
+                                    UTF-8-Encoding-Of( StringToSign ) ) ) );
 
         StringToSign = HTTP-VERB + "\n" +
             Content-MD5 + "\n" +
@@ -112,8 +112,8 @@ class S3Connection(ConnectionUserAndKey):
             CanonicalizedAmzHeaders +
             CanonicalizedResource;
         """
-        special_header_keys = [ 'content-md5', 'content-type', 'date' ]
-        special_header_values = { 'date': '' }
+        special_header_keys = ['content-md5', 'content-type', 'date']
+        special_header_values = {'date': ''}
         amz_header_values = {}
 
         headers_copy = copy.deepcopy(headers)
@@ -136,7 +136,7 @@ class S3Connection(ConnectionUserAndKey):
         keys_sorted = list(special_header_values.keys())
         keys_sorted.sort()
 
-        buf = [ method ]
+        buf = [method]
         for key in keys_sorted:
             value = special_header_values[key]
             buf.append(value)
@@ -152,7 +152,7 @@ class S3Connection(ConnectionUserAndKey):
         amz_header_string = '\n'.join(amz_header_string)
 
         values_to_sign = []
-        for value in [ string_to_sign, amz_header_string, path]:
+        for value in [string_to_sign, amz_header_string, path]:
             if value:
                 values_to_sign.append(value)
 
@@ -162,8 +162,10 @@ class S3Connection(ConnectionUserAndKey):
         )
         return b64_hmac.decode('utf-8')
 
+
 class S3StorageDriver(StorageDriver):
     name = 'Amazon S3 (standard)'
+    website = 'http://aws.amazon.com/s3/'
     connectionCls = S3Connection
     hash_type = 'md5'
     supports_chunked_encoding = False
@@ -181,7 +183,7 @@ class S3StorageDriver(StorageDriver):
                             driver=self)
 
     def list_container_objects(self, container):
-        value_dict = { 'container': container }
+        value_dict = {'container': container}
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
     def get_container(self, container_name):
@@ -189,7 +191,7 @@ class S3StorageDriver(StorageDriver):
         containers = self.list_containers()
 
         try:
-            container = [ c for c in containers if c.name == container_name ][0]
+            container = [c for c in containers if c.name == container_name][0]
         except IndexError:
             raise ContainerDoesNotExistError(value=None, driver=self,
                                              container_name=container_name)
@@ -197,9 +199,9 @@ class S3StorageDriver(StorageDriver):
         return container
 
     def get_object(self, container_name, object_name):
-        # TODO: Figure out what is going on when the object or container does not exist
-        # - it seems that Amazon just keeps the connection open and doesn't return a
-        # response.
+        # TODO: Figure out what is going on when the object or container
+        # does not exist- it seems that Amazon just keeps the connection open
+        # and doesn't return a response.
         container = self.get_container(container_name=container_name)
         response = self.connection.request('/%s/%s' % (container_name,
                                                        object_name),
@@ -235,10 +237,10 @@ class S3StorageDriver(StorageDriver):
             container = Container(name=container_name, extra=None, driver=self)
             return container
         elif response.status == httplib.CONFLICT:
-            raise InvalidContainerNameError(value='Container with this name ' +
-                                'already exists. The name must be unique among '
-                                'all the containers in the system',
-                                container_name=container_name, driver=self)
+            raise InvalidContainerNameError(
+                value='Container with this name already exists. The name must '
+                      'be unique among all the containers in the system',
+                container_name=container_name, driver=self)
         elif response.status == httplib.BAD_REQUEST:
             raise InvalidContainerNameError(value='Container name contains ' +
                                             'invalid characters.',
@@ -255,10 +257,9 @@ class S3StorageDriver(StorageDriver):
         if response.status == httplib.NO_CONTENT:
             return True
         elif response.status == httplib.CONFLICT:
-            raise ContainerIsNotEmptyError(value='Container must be empty' +
-                                                  ' before it can be deleted.',
-                                           container_name=container.name,
-                                           driver=self)
+            raise ContainerIsNotEmptyError(
+                value='Container must be empty before it can be deleted.',
+                container_name=container.name, driver=self)
         elif response.status == httplib.NOT_FOUND:
             raise ContainerDoesNotExistError(value=None,
                                              driver=self,
@@ -278,11 +279,12 @@ class S3StorageDriver(StorageDriver):
 
         return self._get_object(obj=obj, callback=self._save_object,
                                 response=response,
-                                callback_kwargs={'obj': obj,
-                                 'response': response.response,
-                                 'destination_path': destination_path,
-                                 'overwrite_existing': overwrite_existing,
-                                 'delete_on_failure': delete_on_failure},
+                                callback_kwargs={
+                                    'obj': obj,
+                                    'response': response.response,
+                                    'destination_path': destination_path,
+                                    'overwrite_existing': overwrite_existing,
+                                    'delete_on_failure': delete_on_failure},
                                 success_status_code=httplib.OK)
 
     def download_object_as_stream(self, obj, chunk_size=None):
@@ -294,14 +296,20 @@ class S3StorageDriver(StorageDriver):
 
         return self._get_object(obj=obj, callback=read_in_chunks,
                                 response=response,
-                                callback_kwargs={ 'iterator': response.response,
-                                                  'chunk_size': chunk_size},
+                                callback_kwargs={'iterator': response.response,
+                                                 'chunk_size': chunk_size},
                                 success_status_code=httplib.OK)
 
     def upload_object(self, file_path, container, object_name, extra=None,
                       verify_hash=True, ex_storage_class=None):
+        """
+        @inherits: L{StorageDriver.upload_object}
+
+        @param ex_storage_class: Storage class
+        @type ex_storage_class: C{str}
+        """
         upload_func = self._upload_file
-        upload_func_kwargs = { 'file_path': file_path }
+        upload_func_kwargs = {'file_path': file_path}
 
         return self._put_object(container=container, object_name=object_name,
                                 upload_func=upload_func,
@@ -312,8 +320,14 @@ class S3StorageDriver(StorageDriver):
 
     def upload_object_via_stream(self, iterator, container, object_name,
                                  extra=None, ex_storage_class=None):
-        # Amazon S3 does not support chunked transfer encoding so the whole data
-        # is read into memory before uploading the object.
+        """
+        @inherits: L{StorageDriver.upload_object_via_stream}
+
+        @param ex_storage_class: Storage class
+        @type ex_storage_class: C{str}
+        """
+        #Amazon S3 does not support chunked transfer encoding so the whole data
+        #is read into memory before uploading the object.
         upload_func = self._upload_data
         upload_func_kwargs = {}
 
@@ -333,7 +347,7 @@ class S3StorageDriver(StorageDriver):
             return True
         elif response.status == httplib.NOT_FOUND:
             raise ObjectDoesNotExistError(value=None, driver=self,
-                                         object_name=obj.name)
+                                          object_name=obj.name)
 
         return False
 
@@ -353,9 +367,9 @@ class S3StorageDriver(StorageDriver):
 
         if response.status == httplib.OK:
             objects = self._to_objs(obj=response.object,
-                                       xpath='Contents', container=container)
-            is_truncated = response.object.findtext(fixxpath(xpath='IsTruncated',
-                                                   namespace=self.namespace)).lower()
+                                    xpath='Contents', container=container)
+            is_truncated = response.object.findtext(fixxpath(
+                xpath='IsTruncated', namespace=self.namespace)).lower()
             exhausted = (is_truncated == 'false')
 
             if (len(objects) > 0):
@@ -374,7 +388,8 @@ class S3StorageDriver(StorageDriver):
         extra = extra or {}
         storage_class = storage_class or 'standard'
         if storage_class not in ['standard', 'reduced_redundancy']:
-            raise ValueError('Invalid storage class value: %s' % (storage_class))
+            raise ValueError(
+                'Invalid storage class value: %s' % (storage_class))
 
         headers['x-amz-storage-class'] = storage_class.upper()
 
@@ -391,16 +406,13 @@ class S3StorageDriver(StorageDriver):
         request_path = '/%s/%s' % (container_name_cleaned, object_name_cleaned)
         # TODO: Let the underlying exceptions bubble up and capture the SIGPIPE
         # here.
-        # SIGPIPE is thrown if the provided container does not exist or the user
+        #SIGPIPE is thrown if the provided container does not exist or the user
         # does not have correct permission
-        result_dict = self._upload_object(object_name=object_name,
-                                          content_type=content_type,
-                                          upload_func=upload_func,
-                                          upload_func_kwargs=upload_func_kwargs,
-                                          request_path=request_path,
-                                          request_method='PUT',
-                                          headers=headers, file_path=file_path,
-                                          iterator=iterator)
+        result_dict = self._upload_object(
+            object_name=object_name, content_type=content_type,
+            upload_func=upload_func, upload_func_kwargs=upload_func_kwargs,
+            request_path=request_path, request_method='PUT',
+            headers=headers, file_path=file_path, iterator=iterator)
 
         response = result_dict['response']
         bytes_transferred = result_dict['bytes_transferred']
@@ -420,16 +432,18 @@ class S3StorageDriver(StorageDriver):
 
             return obj
         else:
-            raise LibcloudError('Unexpected status code, status_code=%s' % (response.status),
-                                driver=self)
+            raise LibcloudError(
+                'Unexpected status code, status_code=%s' % (response.status),
+                driver=self)
 
     def _to_containers(self, obj, xpath):
-        return [ self._to_container(element) for element in \
-                 obj.findall(fixxpath(xpath=xpath, namespace=self.namespace))]
+        return [self._to_container(element) for element in
+                obj.findall(fixxpath(
+                    xpath=xpath, namespace=self.namespace))]
 
     def _to_objs(self, obj, xpath, container):
-        return [ self._to_obj(element, container) for element in \
-                 obj.findall(fixxpath(xpath=xpath, namespace=self.namespace))]
+        return [self._to_obj(element, container) for element in
+                obj.findall(fixxpath(xpath=xpath, namespace=self.namespace))]
 
     def _to_container(self, element):
         extra = {
@@ -437,21 +451,31 @@ class S3StorageDriver(StorageDriver):
                                       namespace=self.namespace)
         }
 
-        container = Container(
-                        name=findtext(element=element, xpath='Name',
-                                      namespace=self.namespace),
-                        extra=extra,
-                        driver=self
-                    )
+        container = Container(name=findtext(element=element, xpath='Name',
+                                            namespace=self.namespace),
+                              extra=extra,
+                              driver=self
+                              )
 
         return container
 
     def _headers_to_object(self, object_name, container, headers):
-        meta_data = { 'content_type': headers['content-type'] }
         hash = headers['etag'].replace('"', '')
+        extra = {'content_type': headers['content-type'], 'etag': headers['etag']}
+        meta_data = {}
+
+        if 'last-modified' in headers:
+            extra['last_modified'] = headers['last-modified']
+
+        for key, value in headers.items():
+            if not key.lower().startswith('x-amz-meta-'):
+                continue
+
+            key = key.replace('x-amz-meta-', '')
+            meta_data[key] = value
 
         obj = Object(name=object_name, size=headers['content-length'],
-                     hash=hash, extra=None,
+                     hash=hash, extra=extra,
                      meta_data=meta_data,
                      container=container,
                      driver=self)
@@ -463,8 +487,8 @@ class S3StorageDriver(StorageDriver):
         owner_display_name = findtext(element=element,
                                       xpath='Owner/DisplayName',
                                       namespace=self.namespace)
-        meta_data = { 'owner': { 'id': owner_id,
-                                 'display_name':owner_display_name }}
+        meta_data = {'owner': {'id': owner_id,
+                               'display_name': owner_display_name}}
 
         obj = Object(name=findtext(element=element, xpath='Key',
                                    namespace=self.namespace),
@@ -476,45 +500,55 @@ class S3StorageDriver(StorageDriver):
                      meta_data=meta_data,
                      container=container,
                      driver=self
-             )
+                     )
 
         return obj
 
+
 class S3USWestConnection(S3Connection):
     host = S3_US_WEST_HOST
 
+
 class S3USWestStorageDriver(S3StorageDriver):
     name = 'Amazon S3 (us-west-1)'
     connectionCls = S3USWestConnection
     ex_location_name = 'us-west-1'
 
+
 class S3USWestOregonConnection(S3Connection):
     host = S3_US_WEST_OREGON_HOST
 
+
 class S3USWestOregonStorageDriver(S3StorageDriver):
     name = 'Amazon S3 (us-west-2)'
     connectionCls = S3USWestOregonConnection
     ex_location_name = 'us-west-2'
 
+
 class S3EUWestConnection(S3Connection):
     host = S3_EU_WEST_HOST
 
+
 class S3EUWestStorageDriver(S3StorageDriver):
     name = 'Amazon S3 (eu-west-1)'
     connectionCls = S3EUWestConnection
     ex_location_name = 'EU'
 
+
 class S3APSEConnection(S3Connection):
     host = S3_AP_SOUTHEAST_HOST
 
+
 class S3APSEStorageDriver(S3StorageDriver):
     name = 'Amazon S3 (ap-southeast-1)'
     connectionCls = S3APSEConnection
     ex_location_name = 'ap-southeast-1'
 
+
 class S3APNEConnection(S3Connection):
     host = S3_AP_NORTHEAST_HOST
 
+
 class S3APNEStorageDriver(S3StorageDriver):
     name = 'Amazon S3 (ap-northeast-1)'
     connectionCls = S3APNEConnection
